==> mastapy-14.0.0rc2.tar.gz: mastapy-14.0.0rc2/mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.bearings.bearing_designs.rolling import _2205
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Type, Any, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2205.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2205.DiameterSeries
        """
        return _2205.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2205.DiameterSeries.type_()

    @property
    def value(self: "Self") -> "_2205.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_2205.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_2205.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.0.3.post1.tar.gz: mastapy-14.0.3.post1/mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings.bearing_designs.rolling import _2207

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2207.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2207.DiameterSeries
        """
        return _2207.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2207.DiameterSeries.type_()

    @property
    def value(self: "Self") -> "_2207.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_2207.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_2207.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None
